# Launchpy

Python wrapper for the Adobe Launch API.\
This module is named launchpy.

## Installation

You can install the module by realising the following pip command:

`pip install launchpy`

You can access the version of the module that you run via the following attribute:

`launchpy.__version__`

## Content of the module

This module is built around 5 main parts:

- Helping functions [Core Components](./docs/main.md)
- Admin instantiating functions [Admin Class](./docs/admin.md)
- Managing properties [Property Class](./docs/property.md)
- Managing Publishing Cycle [Library Class](./docs/library.md)
- Translator functionationality [Translator Class](./docs/translator.md)
- Synchronizer [Synchronizer Class](./docs/synchronizer.md)

## Get Stated

A [get started guide](./docs/getstarted.md) has been created to explain the different functionality.
You can find a more detail description functionalities at [datanalyst.info](https://datanalyst.info).

~~A Jupyter notebook is also available in the github for demo.~~ To be updated.

## Main documentation

Most of the documentation has been imported from the datanalyst website [here](./docs/main.md).

## Release information

You can find release information [here](./docs/releases.md).
